@@ -249,7 +249,7 @@
             endif
 
             subdc = 1           ! search from the hierarchy top
-            call epGetIndex0(0, Det%nct, subdc, shape, ntbrc,
+            call epGetIndex0(0, Det.nct, subdc, shape, ntbrc,
      *      idarray(occupied+1), arraysize-occupied, judgeBy)
 
             num(ntbrc, OddSubdc) = filledmax(nitem) 
@@ -377,11 +377,10 @@
        integer:: j, m, k, ii, l, prod
        character(len=16):: sname ! subd name
        integer :: msubdi, flag, ll, namec, pos
-       integer :: tempc, nornf, fsubdc
-        ! fsubdc was logical so far( June 17,2016 why was ok?)
-       logical :: ok
-       depth = Det%cmp(i)%level    ! hier depth
-       j = Det%cmp(i)%NMatreska    ! # of contained comp.
+       integer :: tempc, nornf
+       logical :: ok, fsubdc
+       depth = Det.cmp(i).level    ! hier depth
+       j = Det.cmp(i).NMatreska    ! # of contained comp.
        tempc = subdc   ! temporary counter
        do while( tempc > 1 ) 
           ! if the hier depth of i is higher than
@@ -426,7 +425,7 @@
        call epqSubdMediaName(mother, i, sname, subdc, flag)
 !              additional check by user
        if( subdc == nitem ) then
-          call epGetIndexUserChk(mother, i, flag, judgeBy)
+          call epGetIndexUserChk(i, mother, flag, judgeBy)
        endif
 
        if( flag == 0 .and. ( sname == splitSpec(subdc) )) then
@@ -478,7 +477,7 @@
          ! if i  does not belong to a subd, 0 
        do m = j, 1, -1
                  ! for partially contained one, CnArea.... < 0
-          ii =abs( CnArea( Det%cmp(i)%ContainsR+m ) )
+          ii =abs( CnArea( Det.cmp(i).ContainsR+m ) )
           call epGetIndex0(msubdi, ii, subdc, shape, ntbrc,
      *      idarray, size)
        enddo
@@ -497,8 +496,8 @@
        logical::ok
 
           if(dEcpy /= dEdef .or. IOcpy /= IOdef ) then
-             ok =(dEcpy ==  Det%cmp(i)%countDE)  .or.
-     *            (IOcpy ==  Det%cmp(i)%countIO)
+             ok =(dEcpy ==  Det.cmp(i).countDE)  .or.
+     *            (IOcpy ==  Det.cmp(i).countIO)
           else
              ok = .true.
           endif
@@ -591,7 +590,7 @@
                splitSpec(nitem-1) = OddSubdName(OddSubdc)
             endif
 
-            call epCsubdTree0(0, Det%nct, subdc, judgeby)
+            call epCsubdTree0(0, Det.nct, subdc, judgeby)
             num(ntbrc, OddSubdc) = filledmax(nitem)
             if( ntbr == 1 ) then
                shape(1:nitem-1) =
@@ -646,8 +645,8 @@
        integer :: msubdi, flag, ll, namec, pos
        integer :: tempc
 
-       depth = Det%cmp(i)%level
-       j = Det%cmp(i)%NMatreska
+       depth = Det.cmp(i).level
+       j = Det.cmp(i).NMatreska
        tempc = subdc
        do while( tempc > 1 ) 
           if( depth <= depthList(tempc-1) ) then
@@ -691,7 +690,7 @@
          ! if i  does not belong to a subd, 0 
        do m = j, 1, -1
                  ! for partially contained one, CnArea.... < 0
-          ii =abs( CnArea( Det%cmp(i)%ContainsR+m ) )
+          ii =abs( CnArea( Det.cmp(i).ContainsR+m ) )
           call epCsubdTree0(msubdi, ii, subdc)
        enddo
 
@@ -738,11 +737,11 @@
 
       if( flag == 0 ) then
          if( targetcpy == targetdef ) then
-            sname = Det%cmp(i)%matter ! may be alias 
+            sname = Det.cmp(i).matter ! may be alias 
          elseif(targetcpy == 'container') then
             icon = 1
          elseif(targetcpy == 'any') then
-            sname = Det%cmp(i)%matter ! may be alias
+            sname = Det.cmp(i).matter ! may be alias
          elseif(targetcpy == 'subd') then
             icon = 1
          else
@@ -754,9 +753,9 @@
          if( targetcpy == targetdef ) then
             icon = 1
          elseif(targetcpy == 'container') then
-            sname = Det%cmp(i)%matter ! may be alias
+            sname = Det.cmp(i).matter ! may be alias
          elseif(targetcpy == 'any') then
-            sname = Det%cmp(i)%matter ! may be alias
+            sname = Det.cmp(i).matter ! may be alias
          elseif(targetcpy == 'subd') then
          else
             write(0,*) ' target=',targetcpy,
