@@ -18,8 +18,8 @@
       record /epPos/ pp
       call epfpolygonCnst(comp)
       call epDraw_fpolygon0(comp, p, n)
-      if( comp.struc == "fpolygon_yz" .or. 
-     *    comp.struc == "fpolygon_zx"  ) then
+      if( comp.struc(1:11) == "fpolygon_yz" .or. 
+     *    comp.struc(1:11) == "fpolygon_zx"  ) then
          do i = 1, n
             if( p(i).x /= gpsep )   then
                call epc2v_fpolygon(comp, p(i), pp)
