@@ -706,6 +706,7 @@ c     ***********************
 c         epexec for subd
       implicit none
 #include  "Zglobalc.h"
+#include "ZepMaxdef.h"
 #include  "Zep3Vec.h"
 #include  "Zcnfig.h"
 #include "ZepDraw.h"
@@ -715,7 +716,7 @@ c         epexec for subd
 
       integer klena, i, icon
       logical first, showusage 
-      character*8 epparaphrase, tempph
+      character(len=MAX_STRUCCHR) epparaphrase, tempph
       integer  nv
       character*2  dql/' "'/, dqr/'" '/
       real*8 r
@@ -865,6 +866,7 @@ c     ******************
       end
       subroutine epwvtx(ith, io, cmp,  n, p)
       implicit none
+#include "ZepMaxdef.h"
 #include  "Zep3Vec.h"
 #include  "Zcnfig.h"
 #include "ZepDraw.h"
@@ -874,7 +876,7 @@ c     ******************
       integer io            ! input.  logical device for output.
       integer  n            ! input.  number of vertex in p
       record /epPos/  p(n)  ! input.  vertex for gnuplot splot
-      character*8  type
+      character(len=MAX_STRUCCHR) type
 
       record /epPos/ pw
 
