@@ -1,4 +1,5 @@
 c   #include "Zep3Vec.h" must preceed this.
+#include "Zepcondc.h"
 #include "ZepMaxdef.h"
 #include "Zcnfig2.h"
 
@@ -12,7 +13,6 @@ c           configuration of detector
 
 
         logical  Incused      ! #inc is used or not
-        logical  ExistID      ! if id=xxx,bb used somewhere--> t
 	integer ncmax         ! max components
         parameter ( ncmax = MAX_COMPONENT )
 c((((((((((
@@ -79,8 +79,8 @@ c  -------------------------------------------------------------------------
          real*8 orgx, orgy, orgz,
      *          direc(9)
          real   offsetx, offsety, offsetz, MaxPathL
-	  character(MAX_STRUCCHR)::struc
-          character(8):: matter
+	  character(len=MAX_STRUCCHR):: struc
+          character(len=MAX_MEDIANAMELENG):: matter
 	 real  rhoc  ! rho calibration factor 
          real  EminG, EminE, RecoilE ! 
          real  LengGmin, LengChmin 
@@ -169,7 +169,6 @@ c       ********************
 
 	integer Nfield, NsubD, mode, SubDUsed, coment,
      *          PosInDet(maxSubDRef), SubDNumb(maxSubDRef),
-     *          SubDwithID(maxSubD+1),
      *          SumOffset(maxSubDRef), wrtcom, comcounter,
      *          comflag(maxcom), comloc 
 
@@ -181,10 +180,9 @@ c
 !   #endif
         character*80 comarea(maxcom)
         character*24  Field(maxiattr), FieldAsItis(maxiattr)
-        character*131 idis
         character*4 form, OrgEqBy
 c        character*8 SubDName(maxSubD),  PreDefName(NPreDefName)
-        character*16 SubDName(maxSubD)
+        character(len=MAX_STRUCCHR) SubDName(maxSubD)  ! 16--> MAX_STRUCCHR v9.164
         integer SubDUsedList(maxSubD)			      
         character*16 EqName(maxEq)
         real*8  EqValue(maxEq)
@@ -203,13 +201,13 @@ c
         common /Zcnfig/ Det, SubdArea,
      1  SubD,  XYZthick, ORGsubd, PlusF, EqualF, MinusF, 
      2  EqValue, Volat,  VTXx, VTXy, VTXz, VolatEq, 
-     3  PosInDet, SubDNumb, SumOffset, subDwithID,  
+     3  PosInDet, SubDNumb, SumOffset,
      4  CnArea, comflag, CnCounter, AttrCounter, NVTX,
      5  coment, Nequates, cumsubdloc, SubDUsedList,
      6  Nfield, NsubD,  mode, SubDUsed, wrtcom, comcounter,
-     7  comloc, Incused, ExistID,  EqualFshort
+     7  comloc, Incused, 
+     *  EqualFshort
 
         common /Zcnfic/ confdata, comarea, Field, FieldAsItis,
-     *    SubDName, EqName, form, idis, OrgEqBy
-
-
+     *    SubDName, EqName, form, 
+     *   OrgEqBy
