@@ -1,20 +1,19 @@
-!    structure used when tracking a particle in epics
-!    *************************
+c    structure used when tracking a particle in epics
+c    *************************
 #ifdef   PTCL
 #else
 #include  "Zptcl.h"
 #endif
 #include  "ZepPos.h"
 #include  "ZepDirec.h"
-!     ---------------------
-       type epTrack       ! full particle attributes in epics
-       sequence
+c     ---------------------
+      structure /epTrack/      ! full particle attributes in epics
 
-       type(ptcl)::  p    ! basic ptcl attributes
-!               position and time
-       type(epPos)::  pos
+          record /ptcl/ p    ! basic ptcl attributes
+c               position and time
+          record /epPos/ pos
           real*8 t           ! time in length/beta (m)
-       type(epDirec)::  w  ! direction cos.
+          record /epDirec/ w  ! direction cos.
           real*4  wgt      ! weight for thin sampling or scintillation light
                            ! from a cell
 	  real*4  pol      ! polarization of photons (light)
@@ -25,6 +24,6 @@
           integer inciflag  ! for incident particle, 1 is set
                      ! decendents are 0
 	  real*8  user  ! user use.
-       end type epTrack
+      end structure   
 
 
