@@ -1,5 +1,4 @@
-       type urban 
-       sequence
+       structure /urban/
         real*8 OscStr(2), ExcitErg(2), MacroSigma(3), AveN(3),
      *       ExToIoniz, AveIoniz, Zeff,  Smallc2,
      *       Emax, EmaxI, IEmaxI, EmaxByEmaxI, PreSigma3, 
@@ -10,7 +9,7 @@
      *       AveElossByNAtype, ElossByAtype, ElossByBtype, ElossTotal,
      *       AveNThin, EOuter
         integer  Ncoll(3), NAtype, NBtype, LargeN3, NThin
-       end type urban
+       end structure
      	 		
 	  
   
