@@ -1,7 +1,7 @@
       function epCompScrPrs(media,  x) result(ans)
       implicit none
 #include "Zmedia.h"
-       type(epmedia)::  media ! input media
+      record /epmedia/ media ! input media
 !      real(8),intent(in):: Egme ! Eg/me not needed; E indep.
       real(8),intent(in):: x    ! Ee/Eg
       real(8):: ans   !  ds/dx in mb for the media
@@ -9,9 +9,9 @@
       real(8)::epCompScrPr
       integer:: i
       ans = 0.
-      do i = 1, media%noOfElem
+      do i = 1, media.noOfElem
          ans = ans  +
-     *        epCompScrPr(media%elem(i)%Z, x)*media%No(i)
+     *        epCompScrPr(media.elem(i).Z, x)*media.No(i)
       enddo
 !
       end         function epCompScrPrs
@@ -19,7 +19,7 @@
 
 
       function epCompScrPr(z, y) result(ans)
-!         complete screening cross-section by Tsai for pair creation.
+c         complete screening cross-section by Tsai for pair creation.
       implicit none
 #include "Zglobalc.h"
 #include "ZbasicCnst.h"
