@@ -15,6 +15,7 @@ c       subroutine epphotoEp(pe, eg, prob, path)
 
 c       record /photoE/pe  ! input. p.e const
        record  /epmedia/ media   ! from v.8.00
+       intent(in):: media
 
        real*8 eg    ! input. gamma energy in GeV 
        real*8 prob  ! output. prob. per r.l 
@@ -42,6 +43,19 @@ c       else
           tp= ( (media.pe.b2*epi + media.pe.b1)*epi + 
      *      media.pe.b0 ) *
      *      media.pe.fa* media.pe.p * epi
+c//////////////
+!          write(0,*) ' epphotoEp ep=',ep
+!          write(0,*) ' eg=',eg, ' tp =',tp
+!          write(0,*) ' media.pe.b2=',media.pe.b2
+!          write(0,*) ' media.pe.b1=',media.pe.b1
+!          write(0,*) ' media.pe.b0=',media.pe.b0
+!          write(0,*) ' media.pe.fa=',media.pe.fa
+!          write(0,*) ' media.pe.p=',media.pe.p
+!          write(0,*) ' media.pe.l=',media.pe.l
+!          write(0,*) ' media.pe.cr=',media.pe.cr
+!          write(0,*) ' media.Zeff=',media.Zeff
+!c////////////////
+
           if(eg .lt. media.pe.ek ) then
              tp=tp/media.pe.l
           endif
