@@ -69,13 +69,8 @@ c
       use sqtccl
       implicit none
 #include "ZepTrackp.h"
-c//////////////
 #include "ZepTrackv.h"
-c///////////
-c #include "Zep3Vec.h"
-c #include "ZepPos.h"
 #include "Zcnfig.h"
-c  #include "ZepDirec.h"
 #include "Zepdebug.h"
 
 c
@@ -98,16 +93,10 @@ c     pos is may or may not be inside comp.
       record /epPos/ cpos
       record /epDirec/ cdir 
 
-!c///////////////
-!      record /epPos/ posw
-!        -3.9228656       2.3623865     -0.68090251
-!        -3.9279674       2.3714778     
 !   
       call epv2c_sqtccl(comp, pos, cpos)    ! for _y _x, get canonical pos
       call epv2cd_sqtccl(comp, dir, cdir)     ! and dir
 
-
-
       call epbsqtccl0(comp, cpos, cdir, length, icon)
 
       end subroutine epbsqtccl
@@ -150,6 +139,7 @@ c     pos is may or may not be inside comp.
       call kxplbx( pos.x-org.x, pos.y-org.y, pos.z-org.z, 
      *               dir.x, dir.y, dir.z, 
      *               abc.x, abc.y, abc.z, el, icon)
+
       if(icon == -1)  return  ! no crossing 
       if(icon == 1)  then
 !            pos is outside but may cross
@@ -173,6 +163,7 @@ c     pos is may or may not be inside comp.
 !          see if pos is inside. next is exact (polygon approx. of ccl
 !          is consideed)
          call epssqtccl0(comp, pos, icon)
+
          topbot = 0  !  used delicate case where wall may intercept 
                      !  inner point and ceil or floor.
          if(icon ==  0 ) then
@@ -264,8 +255,6 @@ c               if(icon == 0 ) then
 c                  return
 c               endif
                if(inout == 0 ) then
-c                  write(0,*) ' ssqtccl0 and k3inout conflicts'
-c                  write(0,*) ' use inout'
                   if( posIsInCcl ) then
                      return
                   endif
@@ -806,7 +795,6 @@ c
       if(icon == 1 ) return
       !  further check
       call  epssqtccl1(comp, pos, icon)
-
       end subroutine epssqtccl0
 
 
@@ -870,7 +858,7 @@ c
       p32.y = p2.y - p3.y
       p32.z = 0.d0
       call epvectorProd(p14, p32, vprod)
-      if( vprod.z < 0.) then
+      if( vprod.z < 0.) then 
          icon = 0
          return
       else
@@ -948,9 +936,9 @@ c
 c        give the envloping box of the component
 c
       record /Component/ comp  ! input.   component.
-      record /epPos/ org       ! output.  origin of the enveloping box
+      record /epPos/ org       ! in/output.  origin of the enveloping box
                                !          in local coord. 
-      record /ep3Vec/ abc      ! output.  a,b,c of the box
+      record /ep3Vec/ abc      ! in/output.  a,b,c of the box
       real(8):: temp
 
 
@@ -1087,13 +1075,14 @@ c      if(comp.cn /= Compnum ) then  !  honeycomb
       record /epPos/ posc     ! output
 
       call ep_sqtcclCnst(comp)
-      if( comp.struc  == 'sqtccl' ) then
+      if( comp.struc  == 'sqtccl' .or.
+     *    comp.struc  == 'sqtccl_w') then
          posc = posv
-      elseif( comp.struc  == 'sqtccl_z' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_z' ) then
          posc = posv
-      elseif( comp.struc  == 'sqtccl_y' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_y' ) then
          posc = epPos( posv.x, -posv.z, posv.y)
-      elseif( comp.struc  == 'sqtccl_x' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_x' ) then
          posc = epPos( -posv.z, posv.y, posv.x)
       else
          write(0,*) ' comp.struc=', comp.struc,
@@ -1114,13 +1103,14 @@ c      if(comp.cn /= Compnum ) then  !  honeycomb
 
       call ep_sqtcclCnst(comp)
 !           (X,Y,Z)--->(x,y,z)
-      if( comp.struc  == 'sqtccl' ) then
+      if( comp.struc  == 'sqtccl' .or.
+     *    comp.struc  == 'sqtccl_w' ) then
          posv = posc
-      elseif( comp.struc  == 'sqtccl_z' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_z' ) then
          posv = posc
-      elseif( comp.struc  == 'sqtccl_y' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_y' ) then
          posv = epPos( posc.x, posc.z,  -posc.y)
-      elseif( comp.struc  == 'sqtccl_x' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_x' ) then
          posv = epPos( posc.z, posc.y, -posc.x)
       else
          write(0,*) ' comp.struc=', comp.struc,
@@ -1141,13 +1131,14 @@ c      if(comp.cn /= Compnum ) then  !  honeycomb
 
       call ep_sqtcclCnst(comp)
 
-      if( comp.struc  == 'sqtccl' ) then
+      if( comp.struc  == 'sqtccl' .or. 
+     *    comp.struc  == 'sqtccl_w' ) then
          dirc = dirv
-      elseif( comp.struc  == 'sqtccl_z' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_z' ) then
          dirc = dirv
-      elseif( comp.struc  == 'sqtccl_y' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_y' ) then
          dirc = epDirec( dirv.x, -dirv.z, dirv.y)
-      elseif( comp.struc  == 'sqtccl_x' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_x' ) then
          dirc = epDirec( -dirv.z,dirv.y, dirv.x)
       else
          write(0,*) ' comp.struc=', comp.struc,
@@ -1168,13 +1159,14 @@ c      if(comp.cn /= Compnum ) then  !  honeycomb
 
       call ep_sqtcclCnst(comp)
 !           (X,Y,Z)<---(x,y,z)
-      if( comp.struc  == 'sqtccl' ) then
+      if( comp.struc  == 'sqtccl' .or.
+     *    comp.struc  == 'sqtccl_w' ) then
          dirv = dirc
-      elseif( comp.struc  == 'sqtccl' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_z' ) then
          dirv = dirc
-      elseif( comp.struc  == 'sqtccl_y' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_y' ) then
          dirv = epDirec( dirc.x, dirc.z,  -dirc.y)
-      elseif( comp.struc  == 'sqtccl_x' ) then
+      elseif( comp.struc(1:8)  == 'sqtccl_x' ) then
          dirv = epDirec( dirc.z, dirc.y, -dirc.x)
       else
          write(0,*) ' comp.struc=', comp.struc,
