@@ -7,51 +7,38 @@
 !        2) In ccosIntF. instead of epgetxs
 !           use cgetXsec
       subroutine epiniXsMedia
-
-      use modXsecMedia, only: cAllocXsMediaArray, cAllocXsElemArray
+      use modXsecMedia, xmedia=>media, xelement=>element
       implicit none
-   ! NoOfMedia, Media,  here  are used
 #include "ZepTrackv.h"
       integer::i
 
       call cAllocXsMediaArray( NoOfMedia ) ! alloc # of media
-
-
-      
-      do i = 1, NoOfMedia     ! this is in modXsecMedia
-         call cAllocXsElemArray(i, Media(i)%NoOfElem) ! alloc # of
+      do i = 1, NoOfMedia
+         call cAllocXsElemArray(i, Media(i).NoOfElem) ! alloc # of
                 ! elements in each medium
          call epsetXsMedia(i,  Media(i)) ! give some
-! values not chainging
+              ! values not chainging
       enddo
-
-
-
       end      subroutine epiniXsMedia
 
-
       subroutine epsetXsMedia(n, media)
 !                         to avoid name collisions
       use modXsecMedia, xmedia=>media, xelement=>element
       implicit none
 #include "Zmedia.h"
       integer,intent(in)::n ! n-th medium
-       type(epmedia)::  media ! input it's ingredient info.
+      record /epmedia/ media ! input it's ingredient info.
 
       integer:: i
 
-      xmedia(n)%name = media%name
-      xmedia(n)%noOfElem = media%noOfElem
+      xmedia(n)%name = media.name
+      xmedia(n)%noOfElem = media.noOfElem
 
-      xmedia(n)%elem(1:media%noOfElem)%A = 
-     *         media%elem(1:media%noOfElem)%A
-      xmedia(n)%elem(1:media%noOfElem)%Z = 
-     *         media%elem(1:media%noOfElem)%Z
-      xmedia(n)%elem(1:media%noOfElem)%No = 
-     *         media%No(1:media%noOfElem)
-      xmedia(n)%mbtoPkgrm = media%mbtoPgrm/10.d0
-
-      xmedia(n)%elem(1:media%noOfElem)%OrigNo =
-     *     media%OrigNo(1:media%noOfElem)
-      xmedia(n)%sumNo = sum(media%OrigNo(1:media%noOfElem))
+      xmedia(n)%elem(1:media.noOfElem)%A = 
+     *         media.elem(1:media.noOfElem).A
+      xmedia(n)%elem(1:media.noOfElem)%Z = 
+     *         media.elem(1:media.noOfElem).Z
+      xmedia(n)%elem(1:media.noOfElem)%No = 
+     *         media.No(1:media.noOfElem)
+      xmedia(n)%mbtoPkgrm = media.mbtoPgrm/10.d0
       end      subroutine epsetXsMedia
