@@ -7,6 +7,15 @@ c      subroutine epbndry(pos, icon)
 c
 c       current track pos is assumed to be inside the current
 c       component. 
+c    At first, ptcl is inside the world. Then, this routine tries
+c   to find x-point with the wrold itself. It should exit. 
+c   However, there may be  contained components. So x-points
+c   with all ingredients are searched for by using epbndry2
+c   placed not at the first part of epbndry. The nearest 
+c   x-point is selected and return is made with icon = 0.
+c   The ptcl point is moved a little bit (EpsLeng) from the
+c   X-ing point, so it must be inside of the new component.
+c
 c       get the crossing point of cTrack extending from the current
 c       location with a given direction
 c
@@ -27,6 +36,7 @@ c
       record /epTrack/ saveTrack
       integer,save:: PrevNo
       save saveTrack
+      character(len=MAX_STRUCCHR):: basename
 c          present comp, boundary
       call epbndry2(Cn, el, jcon)
       if(jcon .ne. 0) then
@@ -50,40 +60,19 @@ c         issue messages.
             return !  *******
          endif
          if( Bndryerr < 10 ) then
-            call cerrorMsg(' ',  1)
-            call cerrorMsg(
-     *    'If following message comes out at the very beginning of', 1)
-            call cerrorMsg(
-     *    ' an event, better to suspect that your incident particle',1)
-            call cerrorMsg(
-     *    'direction might be wrong; check it.!!!!!', 1)
-            call cerrorMsg(
-     *    'If not,  a particle on or very near to a ', 1)
-            call cerrorMsg(
-     *    'component boundary might have buffalloed Epics.' , 1) 
-            call cerrorMsg(
-     *    'Epics is expected to recover the matter safely.', 1)
-            call cerrorMsg(
-     *    'However, some unknown cause may lead to this, ', 1)
-            call cerrorMsg(
-     *    'so check the coordinate below, if they are very ',1)
-            call cerrorMsg(
-     *      'near to the boundary, it will  be ok', 1)
-            call epfordebug('epbndry')
-            write(msg,*) 'NOTE: local above means local coordinate'
-            call cerrorMsg(msg, 1)
-            write(msg,*)
-     *      '  so  if component name has "_", it is different'
-            call cerrorMsg(msg, 1)
-            write(msg,*) '  from  canonical coordinate'
-            call cerrorMsg(msg, 1)
-            write(msg,*)
-     *      ' cTrack T.E=',cTrack.p.fm.p(4), ' Move TE=',
-     *           Move.Track.p.fm.p(4),  ' code=',cTrack.p.code,
-     *      ' subcode=', cTrack.p.subcode,' chg=',cTrack.p.charge
-            call cerrorMsg(msg,1)
-            call cerrorMsg('-------------------------------',1)
+            call epGetBaseStrucName(Det.cmp(Cn).struc, basename)
+!              sqtccl has some problem and when it is treated
+!              in some case error happens; it is difficult to
+!              fix completely due to numerical error. It is
+!              proved to be non harmul (atuomatically remedied)
+!              so avoid message  until complete fix comes.
+!              But see later, if it is really problem, 
+!              next call will be done for sqtccl too.
+            if( basename /= "sqtccl") then
+               call epIssueBndryErrMsg
+            endif
          endif
+
          if( PrevNo  > 1 ) then
             if( cTrack.p.code /= saveTrack.p.code .or.
      *          cTrack.p.charge /= saveTrack.p.charge .or.
@@ -108,6 +97,7 @@ c         issue messages.
              
          if( Bndryerr  > 
      *     min(500,  max(int(10*Total1ryE/100), 10)) ) then
+           if(basename == "sqtccl")  call  epIssueBndryErrMsg
             call cerrorMsg('too many boundary error', 0)
          endif
          if(Cn .ne. cnxx) then
@@ -170,3 +160,34 @@ c))))))))))
          icon = 0
       endif
       end
+
+      subroutine epIssueBndryErrMsg
+      implicit none
+      call cerrorMsg(' ',  1)
+      call cerrorMsg(
+     *  'If following message comes out at the very beginning of', 1)
+      call cerrorMsg(
+     *  ' an event, better to suspect that your incident particle',1)
+      call cerrorMsg(
+     *  'direction might be wrong; check it.!!!!!', 1)
+      call cerrorMsg(
+     *  'If not,  a particle on or very near to a ', 1)
+      call cerrorMsg(
+     *  'component boundary might have buffalloed Epics.' , 1) 
+      call cerrorMsg(
+     *  'Epics is expected to recover the matter safely.', 1)
+      call cerrorMsg(
+     *  'However, some unknown cause may lead to this, ', 1)
+      call cerrorMsg(
+     *  'so check the coordinate below, if they are very ',1)
+      call cerrorMsg(
+     *  'near to the boundary, it will  be ok', 1)
+      call epfordebug('epbndry')
+      call cerrorMsg(
+     *   'NOTE: local above means local coordinate', 1)
+      call cerrorMsg(
+     *   'so if component name has "_", it is different', 1)
+      call cerrorMsg( '  from  canonical coordinate', 1)
+      call cerrorMsg('-------------------------------',1)
+      end   subroutine epIssueBndryErrMsg
+
