@@ -94,7 +94,10 @@ c))))))))
 c((((((
            attr.x = Volat( Det.cmp(Det.nct).vol+sphr )
 c))))))
-        elseif( Det.cmp(Det.nct).struc == 'cyl_w') then
+        elseif( Det.cmp(Det.nct).struc == 'cyl_w' .or.
+     *    Det.cmp(Det.nct).struc == 'cyl_y_w' .or.
+     *    Det.cmp(Det.nct).struc == 'cyl_x_w' .or.
+     *    Det.cmp(Det.nct).struc == 'cyl_z_w' ) then
            attr.x = Volat(Det.cmp(Det.nct).vol+cylr)
            attr.y = Volat(Det.cmp(Det.nct).vol+cylh)
         else
@@ -140,7 +143,9 @@ c       local coord.
 
 
       character*80 msg
-      character*8  epparaphrase, tempph
+      character(len=MAX_STRUCCHR)::  epparaphrase, tempph
+      character(len=MAX_STRUCCHR)::  basename
+
 
       integer::uscl
 
@@ -149,19 +154,19 @@ c       local coord.
      *     ' not exists: epqenvlper'
          call cerrorMsg(msg, 0)
       endif
-      if(Det.cmp(i).struc(1:3) .eq. 'box') then
+      call epGetBaseStrucName(Det.cmp(i).struc, basename)
+      if(basename .eq. 'box') then
          call epenvlpBox(Det.cmp(i), org, abc)
 
-      elseif(Det.cmp(i).struc(1:3) .eq. 'cyl') then
+      elseif(basename .eq. 'cyl') then
          call epenvlpCyl(Det.cmp(i), org, abc)
 
-      elseif(Det.cmp(i).struc(1:4) .eq. 'pipe') then
+      elseif(basename .eq. 'pipe') then
          call epenvlpPipe(Det.cmp(i), org, abc)
 
-      elseif(Det.cmp(i).struc .eq. 'prism' .or.
-     *       Det.cmp(i).struc(1:6) .eq. 'prism_') then
+      elseif( basename .eq. 'prism' ) then
          call epenvlpPrism(Det.cmp(i), org, abc)
-      elseif(Det.cmp(i).struc(1:6) .eq. 'sphere') then
+      elseif( basename  .eq. 'sphere') then
          call epenvlpSphere(Det.cmp(i), org, abc)
       else
          call epseeUnderScore(Det.cmp(i).struc, uscl)
@@ -417,13 +422,13 @@ c((((((((((((
       abc.z = Volat( comp.vol+cylh )
 c))))))))))
       NVTX = 0
-      if(comp.struc == "cyl_y") then
+      if(comp.struc(1:5) == "cyl_y") then
          call epc2v_cyl(comp, org, org)
 !         temp = abc.y
 c         abc = ep3Vec(abc.x, abc.z, temp)
 !         abc = ep3Vec(temp, abc.z, abc.x)
          call epc2v_cyl(comp, abc, abc)
-      elseif(comp.struc == "cyl_x") then
+      elseif(comp.struc(1:5) == "cyl_x") then
          call epc2v_cyl(comp, org, org)
 !         temp=abc.x
 c         abc = ep3Vec(abc.z, abc.y, temp)
@@ -458,13 +463,13 @@ c))))))))))
       NVTX = 0
 
 
-      if(comp.struc == "pipe_y") then
+      if(comp.struc(1:6) == "pipe_y") then
          call epc2v_pipe(comp, org, org)
 !         temp = abc.y
 c         abc = ep3Vec(abc.x, abc.z, temp)
 !         abc = ep3Vec(temp, abc.z, abc.x)
          call epc2v_pipe(comp, abc, abc)
-      elseif(comp.struc == "pipe_x") then
+      elseif(comp.struc(1:6) == "pipe_x") then
          call epc2v_pipe(comp, org, org)
 !         temp=abc.x
 c         abc = ep3Vec(abc.z, abc.y, temp)
